@@ -1,11 +1,13 @@
 from dataclasses import dataclass, field
 from typing import Callable, List, Optional, Type
+
 from graia.broadcast import Broadcast
-from graia.broadcast.entities.listener import Listener
-from graia.broadcast.entities.event import Dispatchable
 from graia.broadcast.entities.decorator import Decorator
+from graia.broadcast.entities.event import Dispatchable
+from graia.broadcast.entities.listener import Listener
 from graia.broadcast.entities.namespace import Namespace
 from graia.broadcast.typing import T_Dispatcher
+
 from graia.saya.schema import BaseSchema
 
 
@@ -17,7 +19,7 @@ class ListenerSchema(BaseSchema):
     decorators: List[Decorator] = field(default_factory=list)
     priority: int = 16
 
-    def build_listener(self, callable: Callable, broadcast: 'Broadcast'):
+    def build_listener(self, callable: Callable, broadcast: "Broadcast"):
         return Listener(
             callable=callable,
             namespace=self.namespace or broadcast.getDefaultNamespace(),
